@@ -1,9 +1,10 @@
 package App::ansiprintf;
 
-our $VERSION = "2.0602";
-
 use v5.14;
 use warnings;
+use open IO => ':utf8', ':std';
+
+our $VERSION = "2.07";
 
 our $WARN //= $ENV{ANSIPRINTF_WARNING} // 1;
 $SIG{__WARN__} = sub {
@@ -16,7 +17,7 @@ $SIG{__WARN__} = sub {
 };
 
 use Pod::Usage;
-use Text::ANSI::Printf 2.03 qw(ansi_printf);
+use Text::ANSI::Printf qw(ansi_printf);
 $Text::ANSI::Printf::REORDER = 1;
 
 use App::ansiprintf::Util qw(decode_argv unescape);
