@@ -1,6 +1,6 @@
 package Text::ANSI::Printf;
 
-our $VERSION = "2.0602";
+our $VERSION = "2.07";
 
 use v5.14;
 use warnings;
@@ -48,7 +48,7 @@ Text::ANSI::Printf - printf function to print string including ANSI sequence
 
 =head1 VERSION
 
-Version 2.0602
+Version 2.07
 
 =head1 SYNOPSIS
 
@@ -84,7 +84,7 @@ this code produces the output like:
 
 =begin :text
 
-    | Red   | Green | Blue  |
+    | Red      | Green    | Blue     |
 
 =end :text
 
@@ -159,17 +159,17 @@ follows.
 
     use Text::ANSI::Printf 'ansi_printf';
     use Term::ANSIColor::Concise 'ansi_color';
-    ansi_printf("| %-5s | %-5s | %-5s |\n",
-                ansi_color("R", "Red", "GI", "Green", "BIU", "Blue"));
+    ansi_printf("| %-8s | %-8s | %-8s |\n",
+                ansi_color("R" => "Red", "GI" => "Green", "BIU" => "Blue"));
 
 Using the command line interface, C<ansiprintf>, and the companion
 command, C<ansiecho>, the shell command can be executed as follows.
 
-    ansiprintf "| %-5s | %-5s | %-5s |\n" $(ansiecho -cR Red -cGI Green -cBIU Blue)
+    ansiprintf "| %-8s | %-8s | %-8s |\n" $(ansiecho -cR Red -cGI Green -cBIU Blue)
 
 In fact, this can be done with the C<ansiecho> command alone.
 
-    ansiecho -f "| %-5s | %-5s | %-5s |" -cR Red -cGI Green -cBIU Blue
+    ansiecho -f "| %-8s | %-8s | %-8s |" -cR Red -cGI Green -cBIU Blue
 
 =head1 ARGUMENT REORDERING
 
@@ -249,7 +249,7 @@ Kazumasa Utashiro
 
 =head1 LICENSE
 
-Copyright © 2020-2024 Kazumasa Utashiro.
+Copyright © 2020-2025 Kazumasa Utashiro.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
